@@ -533,6 +533,7 @@ get_all_applications_from_dir (GMenuTreeDirectory *directory,
 {
 	GSList *contents;
 	GSList *l;
+	const char *exec;
 
 	contents = gmenu_tree_directory_get_contents (directory);
 
@@ -546,7 +547,14 @@ get_all_applications_from_dir (GMenuTreeDirectory *directory,
 				break;
 
 			case GMENU_TREE_ITEM_ENTRY:
-				list = g_slist_prepend (list, item);
+				exec = gmenu_tree_entry_get_exec ((GMenuTreeEntry*)item);
+				/* Only add items that actually accept a file */
+				if (strstr (exec,"%U") != NULL ||
+				    strstr (exec,"%u") != NULL ||
+				    strstr(exec,"%f") != NULL ||
+				    strstr(exec,"%F") != NULL) {
+					list = g_slist_prepend (list, item);
+				}
 				break;
 
 			default:
